pub struct AutoSleep {
pub threshold: Duration,
pub io_errors_as_flood_of: Option<Duration>,
}Expand description
Retry policy that will retry once on flood-wait and slow mode wait errors.
The library will sleep only if the duration to sleep for is below or equal to the threshold.
Fields
threshold: DurationThe (inclusive) threshold below which the library should automatically sleep.
io_errors_as_flood_of: Option<Duration>Some if I/O errors should be treated as a flood error that would last the specified duration.
This duration will ignore the threshold and always be slept on on the first I/O error.