pub struct ClientConfiguration {
pub retry_policy: Box<dyn RetryPolicy>,
pub auto_cache_peers: bool,
}Expand description
Configuration that controls the Client behaviour when making requests.
Fields
retry_policy: Box<dyn RetryPolicy>The retry policy to use when encountering errors after invoking a request.
auto_cache_peers: boolWhether to call Session::cache_peer on all peer information that
the high-level methods receive as a response (e.g. Client::iter_dialogs).
The cached peers are then usable by other methods such as Client::resolve_peer
for as long as the same persisted session is used.