pub struct MessageIter { /* private fields */ }Expand description
Iterator returned by Client::iter_messages.
Implementations
Sourceimpl MessageIter
impl MessageIter
Sourcepub fn offset_date(self, offset: i32) -> Self
pub fn offset_date(self, offset: i32) -> Self
Changes the starting message date.
Sourcepub fn reverse(self, reverse: bool) -> Self
pub fn reverse(self, reverse: bool) -> Self
Changes the order to oldest-to-newest. (default is newest-to-oldest)
pub fn limit(self, limit: usize) -> Self
Sourcepub async fn total(&mut self) -> Result<usize, InvocationError>
pub async fn total(&mut self) -> Result<usize, InvocationError>
Determines the total number of messages in the chat.
This only performs a network call if next has not been called before.