pub struct ParticipantIter(/* private fields */);Expand description
Iterator returned by Client::iter_participants.
Implementations
Sourceimpl ParticipantIter
impl ParticipantIter
Sourcepub async fn total(&mut self) -> Result<usize, InvocationError>
pub async fn total(&mut self) -> Result<usize, InvocationError>
Determines how many participants there are in total.
This only performs a network call if next has not been called before.
Sourcepub async fn next(&mut self) -> Result<Option<Participant>, InvocationError>
pub async fn next(&mut self) -> Result<Option<Participant>, InvocationError>
Return the next Participant from the internal buffer, filling the buffer previously if
it’s empty.
Returns None if the limit is reached or there are no participants left.
Sourcepub fn filter(self, filter: ChannelParticipantsFilter) -> Self
pub fn filter(self, filter: ChannelParticipantsFilter) -> Self
apply a filter on fetched participants, note that this filter will apply only on large Channel and not small groups