pub struct ProfilePhotoIter(/* private fields */);Expand description
Iterator returned by Client::iter_profile_photos.
Implementations
Sourceimpl ProfilePhotoIter
impl ProfilePhotoIter
Sourcepub async fn total(&mut self) -> Result<usize, InvocationError>
pub async fn total(&mut self) -> Result<usize, InvocationError>
Determines how many profile photos there are in total.
This only performs a network call if next has not been called before.