pub struct RetryContext {
pub fail_count: NonZeroU32,
pub slept_so_far: Duration,
pub error: InvocationError,
}Expand description
Context passed to RetryPolicy::should_retry.
Fields
fail_count: NonZeroU32Amount of times the instance of this request has failed.
slept_so_far: DurationSum of the durations for all previous continuations (not total time elapsed since first failure).
error: InvocationErrorThe most recent error caused by the instance of the request.