pub struct UpdateStream { /* private fields */ }Expand description
Iterator returned by Client::stream_updates.
Implementations
Sourceimpl UpdateStream
impl UpdateStream
Sourcepub async fn next(&mut self) -> Result<Update, InvocationError>
pub async fn next(&mut self) -> Result<Update, InvocationError>
Pops an update from the queue, waiting for an update to arrive first if the queue is empty.
Sourcepub async fn next_raw(
&mut self,
) -> Result<(Update, State, PeerMap), InvocationError>
pub async fn next_raw( &mut self, ) -> Result<(Update, State, PeerMap), InvocationError>
Pops an update from the queue, waiting for an update to arrive first if the queue is empty.
Unlike Self::next, the update is not wrapped at all, but it is still processed.
Sourcepub async fn sync_update_state(&self)
pub async fn sync_update_state(&self)
Synchronize the updates state to the session.
This is not automatically done on drop.