pub struct InlineQuery {
pub raw: Update,
pub state: State,
/* private fields */
}Expand description
Update that bots receive when a user performs an inline query such as @bot query.
Fields
raw: Updatestate: StateImplementations
Sourceimpl InlineQuery
impl InlineQuery
Sourcepub fn sender_id(&self) -> PeerId
pub fn sender_id(&self) -> PeerId
The Self::sender’s identifier.
Sourcepub async fn sender_ref(&self) -> Option<PeerRef>
pub async fn sender_ref(&self) -> Option<PeerRef>
Cached reference to the Self::sender, if it is in cache.
Sourcepub fn answer<T>(&self, results: impl IntoIterator<Item = T>) -> Answerwhere
T: Into<InputBotInlineResult>,
pub fn answer<T>(&self, results: impl IntoIterator<Item = T>) -> Answerwhere
T: Into<InputBotInlineResult>,
Answer the inline query.
Sourcepub fn peer_type(&self) -> Option<InlineQueryPeerType>
pub fn peer_type(&self) -> Option<InlineQueryPeerType>
Type of the peer from which the inline query was sent.