MessageIter

Struct MessageIter 

pub struct MessageIter { /* private fields */ }
Iterator returned by Client::iter_messages.

Implementations

Source

impl MessageIter

pub fn offset_id(self, offset: i32) -> Self

Changes the starting message ID (exclusive).

pub fn offset_date(self, offset: i32) -> Self

Changes the starting message date.

pub fn reverse(self, reverse: bool) -> Self

Changes the order to oldest-to-newest. (default is newest-to-oldest)

pub fn limit(self, limit: usize) -> Self

pub async fn total(&mut self) -> Result<usize, InvocationError>

Determines the total number of messages in the chat.

This only performs a network call if next has not been called before.

pub async fn next(&mut self) -> Result<Option<Message>, InvocationError>

Returns the next Message from the internal buffer, filling the buffer previously if it’s empty.

Returns None if the limit is reached or there are no messages left.