pub type GlobalSearchIter = IterBuffer<SearchGlobal, Message>;Expand description
Iterator returned by Client::search_all_messages.
Aliased Type
pub struct GlobalSearchIter { /* private fields */ }Implementations
Sourceimpl GlobalSearchIter
impl GlobalSearchIter
Sourcepub fn query(self, query: &str) -> Self
pub fn query(self, query: &str) -> Self
Changes the query of the search. Telegram servers perform a somewhat fuzzy search over this query (so a word in singular may also return messages with the word in plural, for example).
Sourcepub fn filter(self, filter: MessagesFilter) -> Self
pub fn filter(self, filter: MessagesFilter) -> Self
Changes the media filter. Only messages with this type of media will be fetched.
Sourcepub async fn total(&mut self) -> Result<usize, InvocationError>
pub async fn total(&mut self) -> Result<usize, InvocationError>
Determines how many messages there are in total.
This only performs a network call if next has not been called before.